Function pieces, specifically Function which is composed of FunctionSignature
and FunctionBody. Naturally, a Function can be used as a “method” for another
object, by specifying self (or some variant of it) as the first Parameter to
a Function object.
Structs
- Function
- Represents a function or method. Determined if any
Parametercontainsself - Function
Body - Represents the function/method’s body
- Function
Signature - Represents a function/method signature in source code
- Parameter
- Represents a single parameter to a
Function